@@ -24,6 +24,8 @@
 
 #include "config.h"
 #include "application.h"
+#include "atom.h"
+#include "bond.h"
 #include "document.h"
 #include "electron.h"
 #include "fragment.h"
@@ -44,18 +46,17 @@
 #include "tool.h"
 #include "tools.h"
 #include "target.h"
+#include "view.h"
 #include "window.h"
 #include "zoomdlg.h"
 #include <gcu/filechooser.h>
 #include <gcu/loader.h>
+#include <goffice/utils/go-file.h>
 #include <goffice/goffice.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/utils/go-file.h>
-#   include <gio/gio.h>
-#endif
 #ifndef HAVE_GO_CONF_SYNC
 #	include <gconf/gconf-client.h>
 #endif
+#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/mol.h>
 #include <openbabel/reaction.h>
@@ -372,7 +373,6 @@ Application::Application ():
 		found = Loader::GetNextLoader (it);
 	}
 	// test if OpenBabel supports some extra types
-	TestSupportedType ("chemical/x-cml");
 	TestSupportedType ("chemical/x-mdl-molfile");
 	TestSupportedType ("chemical/x-pdb");
 	TestSupportedType ("chemical/x-xyz");
@@ -885,7 +885,6 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			g_error_free (error);
 			throw 1;
 		}
-		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
 		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml, 
 				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
 			g_object_unref (file);
@@ -1034,7 +1033,7 @@ void Application::OnToolChanged (GtkAction *current)
 		m_pActiveTool->Activate(true);
 }
 
-void Application::BuildTools () throw (std::runtime_error)
+void Application::BuildTools ()
 {
 	Tools *ToolsBox = new Tools (this);
 	map<int, string>::iterator i, iend = ToolbarNames.end ();
@@ -1049,9 +1048,9 @@ void Application::BuildTools () throw (std::runtime_error)
 	gtk_ui_manager_insert_action_group (ToolsManager, action_group, 0);
 	for (j = UiDescs.begin (); j != jend; j++)
 		if (!gtk_ui_manager_add_ui_from_string (ToolsManager, *j, -1, &error)) {
-			string what = string ("building user interface failed: ") + error->message;
+			g_message ("building user interface failed: %s", error->message);
 			g_error_free (error);
-			throw runtime_error (what);
+			exit (EXIT_FAILURE);
 		}
 	for (i = ToolbarNames.begin (); i != iend; i++) {
 		s = "ui/";
@@ -1110,8 +1109,8 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 				// set the pixbuf color to the corresponding style for the style
 				unsigned char red, blue, green;
 				red = m_Style->fg[c].red >> 8;
-				green = m_Style->fg[c].green >> 8;
-				blue = m_Style->fg[c].blue >> 8;
+				green = m_Style->fg[c].red >> 8;
+				blue = m_Style->fg[c].red >> 8;
 				unsigned char *line, *cur;
 				line = gdk_pixbuf_get_pixels (icon);
 				int i, j, rows, cols, rowstride;
