@@ -4,7 +4,7 @@
  * GChemPaint library
  * arrow.cc 
  *
- * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,20 +23,24 @@
  */
 
 #include "config.h"
-#include "widgetdata.h"
-#include "view.h"
-#include "settings.h"
-#include <canvas/gcp-canvas-line.h>
-#include <canvas/gprintable.h>
 #include "arrow.h"
 #include "document.h"
+#include "settings.h"
+#include "view.h"
+#include "widgetdata.h"
+#include <gcu/objprops.h>
+#include <gccv/group.h>
+#include <gccv/line-item.h>
+#include <list>
 #include <cstring>
 
 using namespace gcu;
 
 namespace gcp {
 
-Arrow::Arrow (TypeId Type): Object (Type)
+Arrow::Arrow (TypeId Type):
+	Object (Type),
+	gccv::ItemClient ()
 {
 }
 
@@ -44,7 +48,7 @@ Arrow::~Arrow ()
 {
 }
 
-bool Arrow::Save (xmlDocPtr xml, xmlNodePtr node)
+bool Arrow::Save (xmlDocPtr xml, xmlNodePtr node) const
 {
 	xmlNodePtr child;
 	gchar buf[16];
@@ -123,11 +127,10 @@ bool Arrow::Load (xmlNodePtr node)
 	return true;
 }
 
-void Arrow::SetSelected (GtkWidget* w, int state)
+void Arrow::SetSelected (int state)
 {
-	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
-	GnomeCanvasGroup* group = pData->Items[this];
-	gchar const *color;
+	gccv::LineItem *line = dynamic_cast <gccv::LineItem *> (m_Item);
+	GOColor color;
 	switch (state) {	
 	case SelStateUnselected:
 		color = Color;
@@ -145,10 +148,20 @@ void Arrow::SetSelected (GtkWidget* w, int state)
 		color = Color;
 		break;
 	}
-	GList* il = group->item_list;
-	while (il) {
-		g_object_set (G_OBJECT(il->data), "fill_color", color, NULL);
-		il = il->next;
+	if (line)
+		line->SetLineColor (color);
+	else {// might be a group
+		gccv::Group *group = dynamic_cast <gccv::Group *> (m_Item);
+		if (!group)
+			return;
+		std::list<gccv::Item *>::iterator it;
+		gccv::Item *item = group->GetFirstChild (it);
+		while (item) {
+			line = dynamic_cast <gccv::LineItem *> (item);
+			if (line)
+				line->SetLineColor (color);
+			item = group->GetNextChild (it);
+		}
 	}
 }
 
@@ -190,4 +203,24 @@ double Arrow::GetYAlign ()
 	return m_y + m_height / 2.;
 }
 
+bool Arrow::SetProperty (unsigned property, char const *value)
+{
+	switch (property) {
+	case GCU_PROP_ARROW_COORDS: {
+		double x0, y0, x1, y1;
+		sscanf (value, "%lg %lg %lg %lg", &x0, &y0, &x1, &y1);
+		gcu::Document *doc = GetDocument ();
+		if (doc) {
+			x0 *= doc->GetScale ();
+			y0 *= doc->GetScale ();
+			x1 *= doc->GetScale ();
+			y1 *= doc->GetScale ();
+		}
+		SetCoords (x0, y0, x1, y1);
+		break;
+	}
+	}
+	return true;
+}
+
 }	//	namespace gcp
