@@ -23,12 +23,14 @@
  */
 
 #include "config.h"
-#include "molecule.h"
-#include "document.h"
-#include "view.h"
 #include "application.h"
-#include "tool.h"
+#include "atom.h"
+#include "bond.h"
+#include "document.h"
+#include "molecule.h"
 #include "stringdlg.h"
+#include "tool.h"
+#include "view.h"
 #include <gcu/chain.h>
 #include <glib/gi18n-lib.h>
 #include <unistd.h>
@@ -99,7 +101,7 @@ Molecule::~Molecule ()
 {
 }
 
-void Molecule::Add (GtkWidget* w) const
+/*void Molecule::Add (GtkWidget* w) const
 {
 	std::list<gcu::Atom*>::const_iterator i, iend = m_Atoms.end ();
 	for (i = m_Atoms.begin (); i != iend; i++)
@@ -110,7 +112,7 @@ void Molecule::Add (GtkWidget* w) const
 	std::list<gcu::Bond*>::const_iterator k, kend = m_Bonds.end ();
 	for (k = m_Bonds.begin (); k != kend; k++)
 		(*k)->Add (w);
-}
+}*/
 
 void Molecule::AddChild (Object* object)
 {
@@ -643,7 +645,7 @@ void Molecule::BuildOBMol (OBMol &Mol)
 			}
 			pBond = (Bond*) pgAtom->GetNextBond (i);
 		}
-		obAtom.SetVector ((xav - x) / 100, (yav - y) / 100, z / 100);
+		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, z / 100);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
@@ -688,25 +690,27 @@ void Molecule::BuildOBMol2D (OBMol &Mol)
 		obAtom.SetAtomicNum (pgAtom->GetZ());
 		pgAtom->GetCoords (&x, &y, &z);
 		// Scans the atom bonds and change z to try conservation of stereochemistry
-		obAtom.SetVector ((x - xav)/ 100, (yav - y) / 100, 0.);
+		obAtom.SetVector ((xav - x )/ 100, (yav - y) / 100, 0.);
 		Mol.AddAtom (obAtom);
 		obAtom.Clear ();
 	}
 	list<gcu::Bond*>::iterator j, endb = m_Bonds.end ();
 	int start, end, order, flag;
-	for (j = m_Bonds.begin (); j != endb; j++) {
+	for (j = m_Bonds.begin (); j != endb; j++)
+	{
 		order = (*j)->GetOrder ();
 		start = AtomTable[(*j)->GetAtom (0)->GetId ()];
 		end = AtomTable[(*j)->GetAtom (1)->GetId ()];
-		switch (reinterpret_cast <Bond *> (*j)->GetType ()) {
-		case UpBondType:
-			flag = OB_WEDGE_BOND;
-			break;
-		case DownBondType:
-			flag = OB_HASH_BOND;
-			break;
-		default:
-			flag = 0;
+		switch((*j)->GetType ())
+		{
+			case UpBondType:
+				flag = OB_WEDGE_BOND;
+				break;
+			case DownBondType:
+				flag = OB_HASH_BOND;
+				break;
+			default:
+				flag = 0;
 		}
 		Mol.AddBond (start, end, order, flag);
 	}
