@@ -27,10 +27,9 @@
 #include "settings.h"
 #include "tool.h"
 #include "tools.h"
+#include <gcu/element.h>
 #include <gcu/gtkcomboperiodic.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/gtk/go-combo-box.h>
-#endif
+#include <goffice/gtk/go-combo-box.h>
 #include <cstring>
 
 using namespace gcu;
