@@ -28,15 +28,16 @@
 The Gnome Chemistry Utils Library provides some widgets and C++ classes related to chemistry.
 
 Available widgets are:
+- GcpFontSel: a font selector.
 - GtkPeriodic: a periodic table of the elements.
 - GtkComboPeriodic: a combo box witha dropdown periodic table widget.
 - GtkCrystalViewer: a crystal structure viewer.
 - GtkChem3DViewer: a 3D molecular structure viewer.
 - GtkSpectrumViewer: a spectrum viewer.
 
-The C++ classes are grouped in the gcu namespace. A C interface exists to use some of the
-functionalities offered in these classes; the corresponding documentation is available in the
-chemistry.h file.
+The C++ classes are grouped in the gcu, gccv, and gcp namespaces. A C interface
+exists to use some (not so many) of the functionalities offered in these classes;
+the corresponding documentation is available in the chemistry.h file.
 */
 
 #ifndef GCU_CHEMISTRY_H
