@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -30,11 +30,10 @@
 #include <gcp/theme.h>
 #include <gcp/view.h>
 #include <gcp/widgetdata.h>
+#include <gccv/structs.h>
 #include <goffice/goffice.h>
-#ifndef GOFFICE_HAS_GLOBAL_HEADER
-#   include <goffice/app/go-plugin.h>
-#   include <goffice/app/go-plugin-loader-module.h>
-#endif
+#include <goffice/app/go-plugin.h>
+#include <goffice/app/go-plugin-loader-module.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
@@ -49,10 +48,6 @@
 #include <string>
 #include <cstring>
 
-#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
-#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
-#endif
-
 using namespace std;
 using namespace gcu;
 
@@ -95,6 +90,7 @@ private:
 	gcp::Document *Doc;
 	map<string, string> Params;
 	MozPaintApp *gcpApp;
+	gcu::Application *App;
 };
 
 ChemComp::ChemComp (void* instance, string& mime_type)
@@ -134,9 +130,9 @@ void ChemComp::SetWindow (XID xid)
 			GDK_WINDOW_XID (Plug->window), xid, 0, 0);
 		XMapWindow (GDK_WINDOW_XDISPLAY (Plug->window),
 			GDK_WINDOW_XID (Plug->window));
-		if (MimeType == "application/x-gcrystal")
+		if (MimeType == "application/x-gcrystal" || MimeType == "chemical/x-cif")
 			Viewer = gtk_crystal_viewer_new (NULL);
-		else if (MimeType == "application/x-gchempaint") {
+		else if (MimeType == "application/x-gchempaint" || MimeType == "chemical/x-cdx" || MimeType == "chemical/x-cdxml") {
 			if (!gcpApp)
 				gcpApp = new MozPaintApp ();
 			Doc = new gcp::Document (gcpApp, true, NULL);
@@ -163,12 +159,17 @@ void ChemComp::SetFilename (string& filename)
 			return;
 		gtk_crystal_viewer_set_data (GTK_CRYSTAL_VIEWER (Viewer), xml->children);
 		xmlFree (xml);
+/*	} else if (MimeType == "chemical/x-cif") {
+		if (!loaded_radii) {
+			Element::LoadRadii ();
+			loaded_radii = true;
+		}*/
 	} else 	if (MimeType == "application/x-gchempaint") {
 		xmlDocPtr xml = xmlParseFile (filename.c_str ());
 		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "chemistry"))
 			return;
 		Doc->Load (xml->children);
-		ArtDRect r;
+		gccv::Rect r;
 		gcp::WidgetData *pData = (gcp::WidgetData*) g_object_get_data (G_OBJECT (Viewer), "data");
 		pData->GetObjectBounds (Doc, &r);
 		gcp::Theme *pTheme = Doc->GetTheme ();
@@ -177,6 +178,10 @@ void ChemComp::SetFilename (string& filename)
 		Doc->GetView ()->Update (Doc);
 		pData->GetObjectBounds (Doc, &r);
 		xmlFree (xml);
+	} else if (MimeType == "chemical/x-cdx" || MimeType == "chemical/x-cdxml") {
+		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
+		gcpApp->Load (uri, MimeType.c_str (), Doc);
+		g_free (uri);
 	} else 	if (MimeType == "chemical/x-jcamp-dx") {
 		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
 		gtk_spectrum_viewer_set_uri (GTK_SPECTRUM_VIEWER (Viewer), uri);
@@ -305,7 +310,7 @@ int main (int argc, char *argv[])
 	}
 #endif
 	libgoffice_init ();
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
 	in_channel = g_io_channel_unix_new (fileno (stdin));
 	g_io_add_watch (in_channel, G_IO_IN, io_func, &error);
 	gtk_main ();
