@@ -14,19 +14,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
- * USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA  02111-1307, USA.
  */
 
 #include <config.h>
 #include "npapi.h"
-#ifdef HAVE_NPFUNCTIONS_H
-#   include "npfunctions.h"
-#else
-#   include "npupp.h"
-#endif
+#include "npupp.h"
 #include <unistd.h>
 #include <string.h>
 
@@ -51,11 +47,7 @@ typedef struct {
 } ChemPlugin;
 
 static NPError ChemNew (NPMIMEType mime_type, NPP instance,
-#ifdef HAVE_NPFUNCTIONS_H
-				 uint16_t mode, uint16_t argc, char *argn[], char *argv[],
-#else
 				 uint16 mode, uint16 argc, char *argn[], char *argv[],
-#endif
 				 NPSavedData *saved)
 {
 	ChemPlugin *plugin;
@@ -109,7 +101,7 @@ static NPError ChemNew (NPMIMEType mime_type, NPP instance,
 	write (to_pipe, mime_type, strlen ((char*) mime_type));
 	write (to_pipe, "\n", 1);
 	i = 0;
-	while (i < argc && strcmp (argn[i++], "PARAM"));
+	while (strcmp (argn[i++], "PARAM"));
 	for (; i < argc; i++) {
 		write (to_pipe, argn[i], strlen (argn[i]));
 		write (to_pipe, "\n", 1);
@@ -153,11 +145,7 @@ static NPError ChemSetWindow (NPP instance, NPWindow *window)
 }
 
 static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
-#ifdef HAVE_NPFUNCTIONS_H
-		      NPBool seekable, uint16_t *stype)
-#else
 		      NPBool seekable, uint16 *stype)
-#endif
 {
 	ChemPlugin *plugin;
 
@@ -212,7 +200,10 @@ char *NP_GetMIMEDescription (void)
 			"chemical/x-pdb:pdb,ent:Protein DataBank;"
 			"chemical/x-jcamp-dx:dx,jdx:JCAMP Spectroscopic Data Exchange Format;"
 			"application/x-gcrystal:gcrystal:Crystalline structure model;"
-			"application/x-gchempaint:gchempaint:2D chemical structures");
+		/*	"chemical/x-cif:cif:Crystallographic Information File;"*/
+			"application/x-gchempaint:gchempaint:2D chemical structures"
+			"chemical/x-cdx:cdx:ChemDraw binary format;"
+			"chemical/x-cdxml:cdxml:ChemDraw CDXML format;");
 }
 
 /* This is called to initialise the plugin
@@ -232,30 +223,15 @@ NPError NP_Initialize(NPNetscapeFuncs *mozFuncs, NPPluginFuncs *pluginFuncs) {
 	
 	pluginFuncs->version    = (NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR;
 	pluginFuncs->size       = sizeof (NPPluginFuncs);
-#ifdef HAVE_NPFUNCTIONS_H
-	pluginFuncs->newp       = (NPP_NewProcPtr)ChemNew;
-	pluginFuncs->destroy    = (NPP_DestroyProcPtr) ChemDestroy;
-	pluginFuncs->setwindow  = (NPP_SetWindowProcPtr) ChemSetWindow;
-	pluginFuncs->newstream  = (NPP_NewStreamProcPtr) ChemNewStream;
-#else
 	pluginFuncs->newp       = NewNPP_NewProc (ChemNew);
 	pluginFuncs->destroy    = NewNPP_DestroyProc (ChemDestroy);
 	pluginFuncs->setwindow  = NewNPP_SetWindowProc (ChemSetWindow);
 	pluginFuncs->newstream  = NewNPP_NewStreamProc (ChemNewStream);
-#endif
 	pluginFuncs->destroystream = NULL;
-#ifdef HAVE_NPFUNCTIONS_H
-	pluginFuncs->asfile     = (NPP_StreamAsFileProcPtr) ChemStreamAsFile;
-#else
 	pluginFuncs->asfile     = NewNPP_StreamAsFileProc (ChemStreamAsFile);
-#endif
 	pluginFuncs->writeready = NULL;
 	pluginFuncs->write      = NULL;
-#ifdef HAVE_NPFUNCTIONS_H
-	pluginFuncs->print      = (NPP_PrintProcPtr) ChemPrint;
-#else
 	pluginFuncs->print      = NewNPP_PrintProc (ChemPrint);
-#endif
 	pluginFuncs->urlnotify  = NULL;
 	pluginFuncs->event      = NULL;
 #ifdef OJI
